library("readxl")
library("ggplot2")
library("ggpubr")

DS <- read_excel("ADD_XLSX_FILE_HERE.xlsx", sheet=1)

# vector assignment and cleaning of NA
q_ax <- DS$"4.assi"[!is.na(DS$"4.assi")]
c_ax <- DS$"5.assi"[!is.na(DS$"5.assi")]

# print vector's characteristics
summary(q_ax)
summary(c_ax)

# cut off value
cut <- 0.1

# partitioning of vectors
q_axpos <- q_ax[q_ax > cut]
q_axneg <- q_ax[q_ax < -cut]

c_axpos <- c_ax[c_ax > cut]
c_axneg <- c_ax[c_ax < -cut]

# structuring data.frames for analysis and display
a <- data.frame(gr="Four axes", v=q_axpos)
b <- data.frame(gr="Five axes", v=c_axpos)
c <- data.frame(gr="Four axes", v=q_axneg)
d <- data.frame(gr="Five axes", v=c_axneg)

# merging of data.frames
plot.datapos <- rbind(a,b)
plot.dataneg <- rbind(c,d)

# preparation of plots
p1 <- ggplot(plot.datapos,aes(x=gr, y=v, fill=gr))+
  geom_boxplot(alpha=0.4, outlier.alpha = 0.1)+
  stat_summary(fun=mean, geom="point", shape=23, size=4)+
  scale_x_discrete(limits=c("Four axes", "Five axes"))+
  coord_cartesian(ylim = c(0, 1))+
  scale_y_continuous(breaks = pretty( c(0,1) , n = 5))+
  labs(title="Positive points", x="", y="values")+
  theme(legend.position="none",
	axis.text.x = element_text(size=13),
	axis.text.y = element_text(size=11),
	axis.ticks.x = element_blank(),
	axis.title = element_text(size=13),
	plot.title = element_text(size=12, face="bold"))

p2 <- ggplot(plot.dataneg,aes(x=gr, y=v, fill=gr))+
  geom_boxplot(alpha=0.4, outlier.alpha = 0.1)+
  stat_summary(fun=mean, geom="point", shape=23, size=4)+
  scale_x_discrete(limits=c("Four axes", "Five axes"))+
  coord_cartesian(ylim = c(-0.8, 0))+
  scale_y_continuous(breaks = pretty( c(-0.8,0) , n = 4))+
  labs(title="Negative points", x="", y="values")+
  theme(legend.position="none",
	axis.text.x = element_text(size=13),
	axis.text.y = element_text(size=11),
	axis.ticks.x = element_blank(),
	axis.title = element_text(size=13),
	plot.title = element_text(size=12, face="bold"))

p3 <- ggplot(plot.datapos, aes(v, color=gr)) +
  geom_histogram(position="identity", binwidth=0.005, aes(y=..density.., fill=gr),  alpha=0.5, size=0.3)+
  labs(title="Positive points", x="values", fill="Simulation")+
  guides(colour="none")+
  coord_cartesian(xlim = c(0, 1))+
  scale_x_continuous(breaks = pretty( c(0,1) , n = 5))+
  theme(legend.position=c(0.8,0.8),
	axis.text.x = element_text(size=11),
	axis.text.y = element_text(size=11),
	axis.title = element_text(size=13),
	plot.title = element_text(size=12, face="bold"))  

p4 <- ggplot(plot.dataneg, aes(v, color=gr)) +
  geom_histogram(position="identity", binwidth=0.005, aes(y=..density.., fill=gr),  alpha=0.5, size=0.3)+
  labs(title="Negative points", x="values")+
  coord_cartesian(xlim = c(-0.8, 0))+
  scale_x_continuous(breaks = pretty( c(-0.8,0) , n = 4))+
  theme(legend.position="none",
	axis.text.x = element_text(size=11),
	axis.text.y = element_text(size=11),
	axis.title = element_text(size=13),
	plot.title = element_text(size=12, face="bold"))

# union and display of plots
ggarrange(p1,p2,ggarrange(p3,p4,nrow=2,labels=c("C","D")),widths=c(1,1,3),ncol=3,labels=c("A","B"))

# length of arrays
length(q_axpos)
length(c_axpos)
length(q_axneg)
length(c_axneg)

# quartiles and mean analyses
summary(q_axpos)
summary(c_axpos)
summary(q_axneg)
summary(c_axneg)

# summatory of array's values
sum(q_axpos)
sum(c_axpos)
sum(q_axneg)
sum(c_axneg)
